@@ -3,11 +3,11 @@ from django.db import models
 from django.utils import timezone
 
 import core.models
-from django.contrib.auth.models import UserManager
+from django.contrib.auth.models import UserManager, PermissionsMixin, Permission, Group
 from compositefk.fields import CompositeForeignKey
+from django.utils.translation import gettext_lazy as _
 
-
-class Profile(AbstractBaseUser, core.models.Log):
+class Profile(AbstractBaseUser, core.models.Log, PermissionsMixin):
     username = models.CharField(max_length=200, unique=True)
     USERNAME_FIELD = 'username'
     is_staff = models.BooleanField(null=True, default=False)
@@ -28,6 +28,34 @@ class Profile(AbstractBaseUser, core.models.Log):
         "tipo": "origem_tipo"
     })
 
+    is_superuser = models.BooleanField(
+        _('superuser status'),
+        default=False,
+        help_text=_(
+            'Designates that this user has all permissions without '
+            'explicitly assigning them.'
+        ),
+    )
+    groups = models.ManyToManyField(
+        Group,
+        verbose_name=_('groups'),
+        blank=True,
+        help_text=_(
+            'The groups this user belongs to. A user will get all permissions '
+            'granted to each of their groups.'
+        ),
+        related_name="%(app_label)s_%(class)s_user_set",
+        related_query_name="user",
+    )
+    user_permissions = models.ManyToManyField(
+        Permission,
+        verbose_name=_('user permissions'),
+        blank=True,
+        help_text=_('Specific permissions for this user.'),
+        related_name="%(app_label)s_%(class)s_user_set",
+        related_query_name="user",
+    )
+
     class Meta(core.models.Log.Meta):
         abstract = True
 
